==> zio-aws-ivs_2.13-5.17.145.1-sources.jar: zio/aws/ivs/model/ListRecordingConfigurationsRequest.scala <==
package zio.aws.ivs.model
import java.lang.Integer
import zio.aws.ivs.model.primitives.{
  PaginationToken,
  MaxRecordingConfigurationResults
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ListRecordingConfigurationsRequest(
    maxResults: Option[MaxRecordingConfigurationResults] = None,
    nextToken: Option[PaginationToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ivs.model.ListRecordingConfigurationsRequest = {
    import ListRecordingConfigurationsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ivs.model.ListRecordingConfigurationsRequest
      .builder()
      .optionallyWith(
        maxResults.map(value =>
          MaxRecordingConfigurationResults.unwrap(value): Integer
        )
      )(_.maxResults)
      .optionallyWith(
        nextToken.map(value => PaginationToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.ivs.model.ListRecordingConfigurationsRequest.ReadOnly =
    zio.aws.ivs.model.ListRecordingConfigurationsRequest.wrap(buildAwsValue())
}
object ListRecordingConfigurationsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ivs.model.ListRecordingConfigurationsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ivs.model.ListRecordingConfigurationsRequest =
      zio.aws.ivs.model.ListRecordingConfigurationsRequest(
        maxResults.map(value => value),
        nextToken.map(value => value)
      )
    def maxResults: Option[MaxRecordingConfigurationResults]
    def nextToken: Option[PaginationToken]
    def getMaxResults: ZIO[Any, AwsError, MaxRecordingConfigurationResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, PaginationToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ivs.model.ListRecordingConfigurationsRequest
  ) extends zio.aws.ivs.model.ListRecordingConfigurationsRequest.ReadOnly {
    override val maxResults: Option[MaxRecordingConfigurationResults] = scala
      .Option(impl.maxResults())
      .map(value =>
        zio.aws.ivs.model.primitives.MaxRecordingConfigurationResults(value)
      )
    override val nextToken: Option[PaginationToken] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.ivs.model.primitives.PaginationToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ivs.model.ListRecordingConfigurationsRequest
  ): zio.aws.ivs.model.ListRecordingConfigurationsRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ivs_2.13-6.20.103.1-sources.jar: zio/aws/ivs/model/ListRecordingConfigurationsRequest.scala <==
package zio.aws.ivs.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.ivs.model.primitives.{
  PaginationToken,
  MaxRecordingConfigurationResults
}
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class ListRecordingConfigurationsRequest(
    maxResults: Optional[MaxRecordingConfigurationResults] = Optional.Absent,
    nextToken: Optional[PaginationToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ivs.model.ListRecordingConfigurationsRequest = {
    import ListRecordingConfigurationsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ivs.model.ListRecordingConfigurationsRequest
      .builder()
      .optionallyWith(
        maxResults.map(value =>
          MaxRecordingConfigurationResults.unwrap(value): Integer
        )
      )(_.maxResults)
      .optionallyWith(
        nextToken.map(value => PaginationToken.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly
      : zio.aws.ivs.model.ListRecordingConfigurationsRequest.ReadOnly =
    zio.aws.ivs.model.ListRecordingConfigurationsRequest.wrap(buildAwsValue())
}
object ListRecordingConfigurationsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ivs.model.ListRecordingConfigurationsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ivs.model.ListRecordingConfigurationsRequest =
      zio.aws.ivs.model.ListRecordingConfigurationsRequest(
        maxResults.map(value => value),
        nextToken.map(value => value)
      )
    def maxResults: Optional[MaxRecordingConfigurationResults]
    def nextToken: Optional[PaginationToken]
    def getMaxResults: ZIO[Any, AwsError, MaxRecordingConfigurationResults] =
      AwsError.unwrapOptionField("maxResults", maxResults)
    def getNextToken: ZIO[Any, AwsError, PaginationToken] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ivs.model.ListRecordingConfigurationsRequest
  ) extends zio.aws.ivs.model.ListRecordingConfigurationsRequest.ReadOnly {
    override val maxResults: Optional[MaxRecordingConfigurationResults] =
      zio.aws.core.internal
        .optionalFromNullable(impl.maxResults())
        .map(value =>
          zio.aws.ivs.model.primitives.MaxRecordingConfigurationResults(value)
        )
    override val nextToken: Optional[PaginationToken] = zio.aws.core.internal
      .optionalFromNullable(impl.nextToken())
      .map(value => zio.aws.ivs.model.primitives.PaginationToken(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ivs.model.ListRecordingConfigurationsRequest
  ): zio.aws.ivs.model.ListRecordingConfigurationsRequest.ReadOnly =
    new Wrapper(impl)
}
